Credits — Stisla

# Credits

## Thanks To ...

We would like to thank the makers of these cool plugins and images.

#### Credits

###### Browser Icons

by Marina D

###### Bootstrap

by @mdo and @fat

###### Bootstrap Color Picker

by Javi Aguilar

###### Bootstrap Date Range

by Dan Grossman

###### Bootstrap Social Button

by Panayiotis Lipiridis

###### Bootstrap Tags Input

by Schlechter

###### Timepicker

by @jdewit

###### Chocolat

by @nicolas-t

###### Cleave.JS

by @nosir

###### Codemirror

by Marijn Haverbeke

###### DataTables

by @datatables

###### Dropzone.JS

by Matias Meno

###### Flag Icon CSS

by Panayiotis Lipiridis

###### Font Awesome

by @fontawesome

###### Full Calendar

by Adam Shaw

###### IonIcons

by Ionic Framework

###### jQuery

by The jQuery Foundation

###### jQuery PWStrength

by Mato Ilic

###### jQuery Selectric

by Leonardo Santos

###### jQuery UI

by The jQuery Foundation

###### jQuery Vector Map

by Manifest Interactive

###### NiceScroll

by InuYaksa

###### OwlCarousel

by David Deutsch

###### Prism

by @PrismJS

###### Select2

by Kevin Brown and Igor Vaynberg

###### Simple Weather

by James Fleeting

###### Summernote

by Alan Hong

###### Sweet Alert

by Tristan Edwards

###### iziToast

by Dolce

###### Upload Preview

by Opoloo

###### Weather Icon

by Erik Flowers

###### Chart.JS

by Nick Downie

###### GMaps.JS

by Gustavo Leon

###### Sparkline

by Gareth Watts

###### Moment

by @moment

###### Popper.JS

by Federico Zivolo

###### Tooltip.JS

by Federico Zivolo